@@ -44,9 +44,11 @@ function(query=NULL, id_list=NULL)
     # do search
     # (extra messy to avoid possible problems when testing on CRAN
     #    timeout_action defined in timeout.R)
+    body <- list(search_query=query, id_list=id_list,
+                 start=0, max_gresults=0)
+    body <- drop_nulls(body)
     search_result <- try(httr::POST(query_url,
-                                    body=list(search_query=query, id_list=id_list,
-                                              start=0, max_gresults=0),
+                                    body=body,
                                     httr::timeout(get_arxiv_timeout())))
     if(class(search_result) == "try-error") {
         timeout_action()
